"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.awaitChunkedPromises = exports.concatLimit = exports.mapLimit = exports.eachOfLimit = void 0;
var tslib_1 = require("tslib");
var async_1 = require("async");
var chunk_1 = tslib_1.__importDefault(require("lodash/chunk"));
var concat_1 = tslib_1.__importDefault(require("lodash/concat"));
/**
 * Для каждого элемента array параллельно вызывает асинхронную функцию cb,
 * но не более limit одновременных вызовов.
 *
 * @param array - массив
 * @param limit - количество одновременно выполняемых операций cb
 * @param cb - колбек, принимающий элемент массива и его индекс
 */
function eachOfLimit(array, limit, cb) {
    return async_1.eachOfLimit(array, limit, async_1.asyncify(cb));
}
exports.eachOfLimit = eachOfLimit;
/**
 * Для каждого элемента array параллельно вызывает асинхронную функцию cb,
 * но не более limit одновременных вызовов.
 *
 * @param array - массив
 * @param limit - количество одновременно выполняемых операций cb
 * @param cb - колбек, принимающий элемент массива и его индекс и возвращающий результат
 * @returns result - массив результатов вызовов cb
 */
function mapLimit(array, limit, cb) {
    return async_1.mapLimit(array, limit, async_1.asyncify(cb));
}
exports.mapLimit = mapLimit;
/**
 * Для каждого элемента array параллельно вызывает асинхронную функцию cb,
 * но не более limit одновременных вызовов.
 *
 * Предполагается, что функция cb возвращает массив.
 * Конкатенирует результирующие массивы в один большой.
 *
 * @param array - массив
 * @param limit - количество одновременно выполняемых операций cb
 * @param cb - колбек, принимающий элемент массива и его индекс и возвращающий массив
 * @returns result - конкатенация результатов вызовов cb для каждого элемента array
 */
function concatLimit(array, limit, cb) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var items;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, mapLimit(array, limit, cb)];
                case 1:
                    items = _a.sent();
                    return [2 /*return*/, concat_1.default.apply(void 0, tslib_1.__spreadArrays([[]], items))];
            }
        });
    });
}
exports.concatLimit = concatLimit;
/**
 * Разбивает массив array на чанки размера chunkSize и выполняет для каждого чанка
 * асинхронную функцию cb параллельно с ограничением в callLimit одновременных вызовов.
 *
 * @param array
 * @param chunkSize
 * @param callLimit
 * @param cb
 */
function awaitChunkedPromises(array, chunkSize, callLimit, cb) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var chunks, nChunks;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    chunks = chunk_1.default(array, chunkSize);
                    nChunks = chunks.length;
                    return [4 /*yield*/, mapLimit(chunks, callLimit, function (slice, iSlice) {
                            return cb(slice, iSlice, nChunks);
                        })];
                case 1: return [2 /*return*/, _a.sent()];
            }
        });
    });
}
exports.awaitChunkedPromises = awaitChunkedPromises;
//# sourceMappingURL=async.js.map