import { IterableCollection } from 'async';
/**
 * Для каждого элемента array параллельно вызывает асинхронную функцию cb,
 * но не более limit одновременных вызовов.
 *
 * @param array - массив
 * @param limit - количество одновременно выполняемых операций cb
 * @param cb - колбек, принимающий элемент массива и его индекс
 */
export declare function eachOfLimit<T>(array: IterableCollection<T>, limit: number, cb: (item: T, index: number) => Promise<void>): Promise<void>;
/**
 * Для каждого элемента array параллельно вызывает асинхронную функцию cb,
 * но не более limit одновременных вызовов.
 *
 * @param array - массив
 * @param limit - количество одновременно выполняемых операций cb
 * @param cb - колбек, принимающий элемент массива и его индекс и возвращающий результат
 * @returns result - массив результатов вызовов cb
 */
export declare function mapLimit<T, R>(array: IterableCollection<T>, limit: number, cb: (item: T, index: number) => Promise<R>): Promise<R[]>;
/**
 * Для каждого элемента array параллельно вызывает асинхронную функцию cb,
 * но не более limit одновременных вызовов.
 *
 * Предполагается, что функция cb возвращает массив.
 * Конкатенирует результирующие массивы в один большой.
 *
 * @param array - массив
 * @param limit - количество одновременно выполняемых операций cb
 * @param cb - колбек, принимающий элемент массива и его индекс и возвращающий массив
 * @returns result - конкатенация результатов вызовов cb для каждого элемента array
 */
export declare function concatLimit<T, R>(array: IterableCollection<T>, limit: number, cb: (item: T, index: number) => Promise<R[]>): Promise<R[]>;
/**
 * Разбивает массив array на чанки размера chunkSize и выполняет для каждого чанка
 * асинхронную функцию cb параллельно с ограничением в callLimit одновременных вызовов.
 *
 * @param array
 * @param chunkSize
 * @param callLimit
 * @param cb
 */
export declare function awaitChunkedPromises<T, R>(array: T[], chunkSize: number, callLimit: number, cb: (slice: T[], iSlice: number, nChunks: number) => Promise<R>): Promise<R[]>;
