/**
 * Класс, управляющий одним таймаутом.
 * Удобен в случаях, когда при назначении нового таймаута старый необходимо отменить,
 * либо когда таймаут должен быть отменен при наступлении внешнего события
 * независимо от того, установлен он или нет.
 *
 * По сути делает таймаут локальным, а не глобальным.
 *
 * Может использоваться с React-компонентами через хук useTimeoutRef.
 */
export declare class SingleTimeoutManager {
    /**
     * Идентификатор активного таймаута.
     * Равен null, если таймаут не запущен или уже сработал.
     */
    timeout: any;
    /**
     * Запускает таймаут, отменяя предыдущий.
     *
     * @param cb - колбек, который будет вызван не раньше, чем через время time
     * @param time - время в мс, через которое будет вызван cb
     */
    set(cb: (() => void) | null | undefined, time: number): void;
    /**
     * Создает таймаут-пустышку.
     *
     * @param time - время в мс, через которое таймаут будет снят
     */
    setDelay(time: number): void;
    /**
     * Если таймаут запущен, то отменяет его.
     */
    clear(): void;
    /**
     * Возвращает идентификатор активного таймаута
     */
    active(): boolean;
}
