/**
 * Возвращает красивое круглое число, не сильно больше переданного
 * @param number {number}
 * @returns {number}
 */
export function roundToRound(number) {
    if (!number)
        return number;
    var log10 = Math.log10(number);
    var floor = Math.floor(log10);
    var ceil = Math.ceil(log10);
    var fl10 = Math.pow(10, floor);
    var steps = number / fl10;
    if (steps >= 8) {
        return Math.pow(10, ceil);
    }
    if (steps <= 3) {
        return (Math.ceil(steps * 2) * fl10) / 2;
    }
    if (steps <= 1) {
        return (Math.ceil(steps * 10) * fl10) / 10;
    }
    return Math.ceil(steps) * fl10;
}
/**
 * Подбирает количество шагов легенды, чтобы цифры были красивые
 * @param max {number} - верхняя граница
 * @param min {number} - нижняя граница
 * @param decimals {number} - количество точек после запятой
 * @param maxSteps {number} - максимум шагов
 * @param minSteps {number} - миниммум шагов
 * @returns {number}
 */
export function getRoundLegendSteps(max, min, decimals, maxSteps, minSteps) {
    if (min === void 0) { min = 0; }
    if (decimals === void 0) { decimals = 0; }
    if (maxSteps === void 0) { maxSteps = 11; }
    if (minSteps === void 0) { minSteps = 5; }
    var maxRounds = 0;
    var maxRoundsSteps = minSteps;
    for (var steps = minSteps; steps <= maxSteps; steps++) {
        var step = (max - min) / (steps - 1);
        var nRounds = 0;
        var value = min;
        for (var i = 0; i <= steps; i++) {
            var label = value.toFixed(decimals).toString();
            var zeros = 0;
            for (var k = label.length - 1; k >= 0; k--) {
                if (label[k] === '0') {
                    zeros++;
                }
                else {
                    break;
                }
            }
            nRounds += zeros;
            value += step;
        }
        if (nRounds > maxRounds) {
            maxRounds = nRounds;
            maxRoundsSteps = steps;
        }
    }
    return maxRoundsSteps;
}
/**
 * Считает оптимальное количество знаков после запятой для легенды графика
 *
 * @param min - минимальное значение легенды
 * @param max - максимальное значение легенды
 * @param legendSteps - количество шагов легенды
 */
export function getLegendDecimals(min, max, legendSteps) {
    if (legendSteps === void 0) { legendSteps = 5; }
    var step = Math.abs((max - min) / legendSteps);
    var log10 = Math.floor(Math.log10(step));
    if (step === 0) {
        return 0;
    }
    if (log10 < 0) {
        return Math.abs(log10);
    }
    return 0;
}
//# sourceMappingURL=chartLegend.js.map