/**
 * Проверяет, что значение является валидным числом (не NaN и не Infinity)
 * @param n - значение для проверки
 */
export function isValidNumber(n) {
    return typeof n == 'number' && !isNaN(n) && isFinite(n);
}
/**
 * Пытается представить value как валидное число и возвращает его в случае успеха.
 * В случае неудачи возвращает null
 *
 * @param value - значение для проверки
 * @param defaultValue - значение по-умолчанию
 */
export function tryNumber(value, defaultValue) {
    if (value === undefined || value === null || value === '') {
        return defaultValue !== null && defaultValue !== void 0 ? defaultValue : null;
    }
    var number = +value;
    if (isValidNumber(number)) {
        return number;
    }
    return defaultValue !== null && defaultValue !== void 0 ? defaultValue : null;
}
//# sourceMappingURL=tryNumber.js.map