"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findMinWrapped = void 0;
var array_1 = require("../array");
/**
 * Находит ближайшую к текущему значение вариацию следующего значения на замкнутом интервале
 *
 * @param current - текущее значение
 * @param next - следующее значение
 * @param wrap - период замкнутого интервала
 * @returns Одно из значений вида `next +- n * wrap`, которое ближе всего к `current` с учетом замкнутости
 * @example
 *  Эта функция может быть полезна для формирования плавных анимаций,
 *  например между углами:
 *
 *  findMinWrapped(15, 350, 360) -> -10
 *
 *  Угол -10 градусов равен углу 350 градусов. Периодичность градусов - 360.
 *  Но анимация от 15 до -10 получится более корректный, чем от 15 до 350.
 */
function findMinWrapped(current, next, wrap) {
    var shift = wrap * Math.floor(current / wrap);
    var options = [shift + next, shift - wrap + next, shift + wrap + next];
    var minIndex = array_1.findMinIndex(options, function (v) { return Math.abs(v - current); });
    return options[minIndex];
}
exports.findMinWrapped = findMinWrapped;
//# sourceMappingURL=findMinWrapped.js.map