/**
 * Форматирует число в русской локали с пробелами-разделителями и запятой.
 *
 * Рекомендуется вместо этой функции использовать Intl.NumberFormat
 *
 * @param number - число
 * @param decimals - количество знаков после запятой
 * @param hideTrailingZeroes - убрать ли крайние правые нули
 */
export declare function formatNumber(number: number | null | undefined, decimals?: number, hideTrailingZeroes?: boolean): string;
/**
 * Единица измерения в русской локали.
 * Если представлена в виде массива, то содержит соответствующие склонения числительных
 *
 * @example [' штука', ' штуки', ' штук']
 */
export declare type Unit = string | [string, string, string];
/**
 * Форматирует число с единицей измерения в русской локали
 *
 * @param value - число
 * @param unit - единица измерения
 * @param decimals - количество знаков после запятой
 */
export declare function formatValueUnit(value: number, unit: Unit, decimals?: number): string;
/**
 * Склоняет единицу измерения
 * @param number - число
 * @param unit - единица измерения
 */
export declare function declineUnit(number: number, unit: Unit): string;
/**
 * Форматирует долю как проценты с одним знаком после запятой
 * @param first - число
 * @param second - число, соответствующее 100 процентам
 */
export declare const formatPercent: (first: number, second?: number) => string;
