"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatPercent = exports.declineUnit = exports.formatValueUnit = exports.formatNumber = void 0;
var utf_1 = require("../utf");
var declinedText_1 = require("../string/declinedText");
/**
 * Форматирует число в русской локали с пробелами-разделителями и запятой.
 *
 * Рекомендуется вместо этой функции использовать Intl.NumberFormat
 *
 * @param number - число
 * @param decimals - количество знаков после запятой
 * @param hideTrailingZeroes - убрать ли крайние правые нули
 */
function formatNumber(number, decimals, hideTrailingZeroes) {
    if (decimals === void 0) { decimals = 2; }
    if (hideTrailingZeroes === void 0) { hideTrailingZeroes = false; }
    if (number === null || number === undefined)
        return utf_1.EMDASH;
    var withTrailingZeroes = Number(number).toFixed(decimals);
    var baseNumber = hideTrailingZeroes
        ? String(parseFloat(withTrailingZeroes))
        : withTrailingZeroes;
    var formattedNum = baseNumber
        .replace(/(\d)(?=(\d\d\d)+([^\d]|$))/g, '$1' + utf_1.QUARTERSP)
        .replace('.', ',');
    if (formattedNum === 'NaN') {
        return utf_1.EMDASH;
    }
    if (formattedNum === 'Infinity') {
        return utf_1.EMDASH;
    }
    return formattedNum;
}
exports.formatNumber = formatNumber;
/**
 * Форматирует число с единицей измерения в русской локали
 *
 * @param value - число
 * @param unit - единица измерения
 * @param decimals - количество знаков после запятой
 */
function formatValueUnit(value, unit, decimals) {
    if (decimals === void 0) { decimals = 2; }
    return formatNumber(value, decimals) + declineUnit(value, unit);
}
exports.formatValueUnit = formatValueUnit;
/**
 * Склоняет единицу измерения
 * @param number - число
 * @param unit - единица измерения
 */
function declineUnit(number, unit) {
    if (Array.isArray(unit)) {
        return declinedText_1.declinedText(number, unit[0], unit[1], unit[2]);
    }
    return unit;
}
exports.declineUnit = declineUnit;
/**
 * Форматирует долю как проценты с одним знаком после запятой
 * @param first - число
 * @param second - число, соответствующее 100 процентам
 */
var formatPercent = function (first, second) {
    if (second === void 0) { second = 1; }
    return formatValueUnit((first / second) * 100, '%', 1);
};
exports.formatPercent = formatPercent;
//# sourceMappingURL=formatNumber.js.map