/**
 * Создаёт функцию, которая проверяет, что переданный элемент
 * подходит под поисковый запрос
 *
 * @param query - поисковый запрос
 * @example
 *  const filter = createFilterSearch('a b');
 *  filter('abc') -> false
 *  filter('aec bcd') -> true
 *  filter('bce daf') -> false
 */
export declare function createFilterSearch(query: string | null | undefined): (item: string) => boolean;
/**
 * Те ключи объекта Obj, которые имеют строки в качестве значения
 */
export declare type StringKeysOf<Obj extends {}> = {
    [Key in keyof Obj]: Obj[Key] extends string ? Key : never;
}[keyof Obj];
/**
 * Фильтрует массив по поисковому запросу с учетом порядка слов
 *
 * @param query - поисковый запрос
 * @param array - массив который фильтруем
 * @param field - свойство массива с именем
 */
export declare function filterSearch<T extends string | object>(query: string | null | undefined, array: T[] | null | undefined, field?: StringKeysOf<T> | ((obj: T) => string)): T[];
